@@ -2,7 +2,7 @@ package Mojo::PDF;
 
 use Mojo::Base -base;
 
-our $VERSION = '1.005001'; # VERSION
+our $VERSION = '1.005002'; # VERSION
 
 use Carp qw/croak/;
 $Carp::Internal{ (__PACKAGE__) }++;
@@ -167,6 +167,12 @@ sub page {
     $self;
 }
 
+sub raw {
+    my $self = shift;
+    prAdd shift;
+    $self;
+}
+
 sub rule {
     my ( $self, %new ) = @_;
     my $rules = $self->_rules;
@@ -376,6 +382,18 @@ Unless otherwise indicated, all methods return their invocant.
 Creates a new C<Mojo::PDF> object. Takes one mandatory argument: the filename
 of the PDF you want to generate, followed by optional key/value attributes.
 
+If filename is not specified or C<undef>, the PDF will be output to C<STDOUT>.
+An L<IO::String> object can be specified to output the PDF into a variable:
+
+    # IO::String
+    my $pdf = Mojo::PDF->new(IO::String->new(my $pdf_bytes));
+    $pdf->text('Viva la Mojo!', 306, 396)->end;
+
+    # Then use the bytes somewhere:
+    open my $fh, '>', 'the.pdf' or die $!;
+    print $fh $pdf_bytes;
+    close $fh;
+
 =head3 C<page_size>
 
 Array reference containing the XxY page size in pixels. Defaults to [612, 792]
@@ -437,6 +455,15 @@ which defaults to the first page.
 
 Add a new blank page to your document and sets it as the currently active page.
 
+=head2 C<raw>
+
+    $pdf->raw("0 0 m\n10 10 l\nS\nh\n");
+
+Use L<prAdd|PDF::Reuse/"prAdd"> to "add whatever you want to the current content stream".
+
+See, for example, section 4.4.1 on page 196 of the
+L<Adobe Acrobat SDK PDF Reference Manual|https://web.archive.org/web/20060212001631/http://partners.adobe.com/public/developer/en/acrobat/sdk/pdf/pdf_creation_apis_and_specs/PDFReference.pdf>.
+
 =head2 C<rule>
 
     ->rule(
